@@ -28,8 +28,8 @@ class Imagen(nn.Module):
             self,
             unets: Union[Unet, List[Unet], Tuple[Unet, ...]],
             *,
+            text_encoder_name: str,
             image_sizes: Union[int, List[int], Tuple[int, ...]],
-            text_encoder_name: str = 't5_small',
             text_embed_dim: int = None,
             channels: int = 3,
             timesteps: Union[int, List[int], Tuple[int, ...]] = 1000,
