@@ -487,9 +487,10 @@ class Unet(nn.Module):
 
             - :code:`cond_scale = 1` => standard conditional model.
 
-            - :code:`cond_scale > 1` => large guidance weights improve image quality/fidelity at the cost of diversity. See
-            `here <https://www.assemblyai.com/blog/how-imagen-actually-works/#large-guidance-weight-samplers>`_ for
+            - :code:`cond_scale > 1` => large guidance weights improve image quality/fidelity at the cost of diversity.
+            See `here <https://www.assemblyai.com/blog/how-imagen-actually-works/#large-guidance-weight-samplers>`_ for
             more information.
+
         :param kwargs: Keyword arguments to pass to :code:`forward`
         :return: Guided images. Shape (b, c, s, s).
         """
@@ -635,7 +636,7 @@ class Unet(nn.Module):
 
 class Base(Unet):
     """
-    Base image generation U-Net with default arguments.
+    Base image generation U-Net with default arguments from original Imagen implementation.
 
     - dim = 512
 
@@ -665,7 +666,7 @@ class Base(Unet):
 
 class Super(Unet):
     """
-    Super-Resolution U-Net with default arguments.
+    Super-Resolution U-Net with default arguments from original Imagen implementation.
 
     - dim = 128
 
@@ -689,3 +690,61 @@ class Super(Unet):
     )
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **{**Super.defaults, **kwargs})
+
+
+class BaseTest(Unet):
+    """
+    Base image generation U-Net with default arguments intended for testing.
+
+    - dim = 8
+
+    - dim_mults = (1, 2)
+
+    - num_resnet_blocks = 1
+
+    - layer_attns = False
+
+    - layer_cross_attns = False
+
+    - memory_efficient = False
+    """
+
+    defaults = dict(
+        dim=8,
+        dim_mults=(1, 2),
+        num_resnet_blocks=1,
+        layer_attns=False,
+        layer_cross_attns=False,
+        memory_efficient=False
+    )
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **{**Base.defaults, **kwargs})
+
+
+class SuperTest(Unet):
+    """
+    Super-Resolution U-Net with default arguments intended for testing.
+
+    - dim = 8
+
+    - dim_mults = (1, 2)
+
+    - num_resnet_blocks = (1, 2)
+
+    - layer_attns = False
+
+    - layer_cross_attns = False
+
+    - memory_efficient = True
+    """
+    defaults = dict(
+        dim=8,
+        dim_mults=(1, 2),
+        num_resnet_blocks=(1, 2),
+        layer_attns=False,
+        layer_cross_attns=False,
+        memory_efficient=True
+    )
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **{**Super.defaults, **kwargs})
\ No newline at end of file
